@@ -1,9 +1,9 @@
 package Log::ger::Output::Composite;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-07'; # DATE
+our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger-Output-Composite'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use strict;
 use warnings;
@@ -13,6 +13,10 @@ use Log::ger::Util;
 # precedence.
 our $Current_Level;
 
+sub meta { +{
+    v => 1,
+} }
+
 sub _get_min_max_level {
     my $level = shift;
     my ($min, $max);
@@ -283,7 +287,7 @@ Log::ger::Output::Composite - Composite output
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
